@@ -23,11 +23,10 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.core
-import constructs
-
 from ._jsii import *
 
+import aws_cdk.core
+
 
 @jsii.implements(aws_cdk.core.IInspectable)
 class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-athena.CfnNamedQuery"):
@@ -95,6 +94,15 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
+    @builtins.property
+    @jsii.member(jsii_name="attrNamedQueryId")
+    def attr_named_query_id(self) -> str:
+        """
+        cloudformationAttribute:
+        :cloudformationAttribute:: NamedQueryId
+        """
+        return jsii.get(self, "attrNamedQueryId")
+
     @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
@@ -111,7 +119,7 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "database")
 
     @database.setter
-    def database(self, value: str):
+    def database(self, value: str) -> None:
         jsii.set(self, "database", value)
 
     @builtins.property
@@ -125,7 +133,7 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "queryString")
 
     @query_string.setter
-    def query_string(self, value: str):
+    def query_string(self, value: str) -> None:
         jsii.set(self, "queryString", value)
 
     @builtins.property
@@ -139,7 +147,7 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "description")
 
     @description.setter
-    def description(self, value: typing.Optional[str]):
+    def description(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "description", value)
 
     @builtins.property
@@ -153,7 +161,7 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: typing.Optional[str]):
+    def name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "name", value)
 
 
@@ -232,7 +240,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
     cloudformationResource:
     :cloudformationResource:: AWS::Athena::WorkGroup
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, description: typing.Optional[str]=None, recursive_delete_option: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, state: typing.Optional[str]=None, tags: typing.Optional["TagsProperty"]=None, work_group_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WorkGroupConfigurationProperty"]]]=None, work_group_configuration_updates: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WorkGroupConfigurationUpdatesProperty"]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, description: typing.Optional[str]=None, recursive_delete_option: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, state: typing.Optional[str]=None, tags: typing.Optional["TagsProperty"]=None, work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]]=None, work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"]]=None) -> None:
         """Create a new ``AWS::Athena::WorkGroup``.
 
         :param scope: - scope in which this resource is defined.
@@ -327,7 +335,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
@@ -341,12 +349,12 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "description")
 
     @description.setter
-    def description(self, value: typing.Optional[str]):
+    def description(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "description", value)
 
     @builtins.property
     @jsii.member(jsii_name="recursiveDeleteOption")
-    def recursive_delete_option(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def recursive_delete_option(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::Athena::WorkGroup.RecursiveDeleteOption``.
 
         see
@@ -355,7 +363,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "recursiveDeleteOption")
 
     @recursive_delete_option.setter
-    def recursive_delete_option(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]):
+    def recursive_delete_option(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
         jsii.set(self, "recursiveDeleteOption", value)
 
     @builtins.property
@@ -369,12 +377,12 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "state")
 
     @state.setter
-    def state(self, value: typing.Optional[str]):
+    def state(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "state", value)
 
     @builtins.property
     @jsii.member(jsii_name="workGroupConfiguration")
-    def work_group_configuration(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WorkGroupConfigurationProperty"]]]:
+    def work_group_configuration(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
 
         see
@@ -383,12 +391,12 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "workGroupConfiguration")
 
     @work_group_configuration.setter
-    def work_group_configuration(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WorkGroupConfigurationProperty"]]]):
+    def work_group_configuration(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]]) -> None:
         jsii.set(self, "workGroupConfiguration", value)
 
     @builtins.property
     @jsii.member(jsii_name="workGroupConfigurationUpdates")
-    def work_group_configuration_updates(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WorkGroupConfigurationUpdatesProperty"]]]:
+    def work_group_configuration_updates(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
         see
@@ -397,7 +405,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "workGroupConfigurationUpdates")
 
     @work_group_configuration_updates.setter
-    def work_group_configuration_updates(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WorkGroupConfigurationUpdatesProperty"]]]):
+    def work_group_configuration_updates(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"]]) -> None:
         jsii.set(self, "workGroupConfigurationUpdates", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.EncryptionConfigurationProperty", jsii_struct_bases=[], name_mapping={'encryption_option': 'encryptionOption', 'kms_key': 'kmsKey'})
@@ -445,7 +453,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.ResultConfigurationProperty", jsii_struct_bases=[], name_mapping={'encryption_configuration': 'encryptionConfiguration', 'output_location': 'outputLocation'})
     class ResultConfigurationProperty():
-        def __init__(self, *, encryption_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.EncryptionConfigurationProperty"]]]=None, output_location: typing.Optional[str]=None) -> None:
+        def __init__(self, *, encryption_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"]]=None, output_location: typing.Optional[str]=None) -> None:
             """
             :param encryption_configuration: ``CfnWorkGroup.ResultConfigurationProperty.EncryptionConfiguration``.
             :param output_location: ``CfnWorkGroup.ResultConfigurationProperty.OutputLocation``.
@@ -459,7 +467,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             if output_location is not None: self._values["output_location"] = output_location
 
         @builtins.property
-        def encryption_configuration(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.EncryptionConfigurationProperty"]]]:
+        def encryption_configuration(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"]]:
             """``CfnWorkGroup.ResultConfigurationProperty.EncryptionConfiguration``.
 
             see
@@ -488,7 +496,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.ResultConfigurationUpdatesProperty", jsii_struct_bases=[], name_mapping={'encryption_configuration': 'encryptionConfiguration', 'output_location': 'outputLocation', 'remove_encryption_configuration': 'removeEncryptionConfiguration', 'remove_output_location': 'removeOutputLocation'})
     class ResultConfigurationUpdatesProperty():
-        def __init__(self, *, encryption_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.EncryptionConfigurationProperty"]]]=None, output_location: typing.Optional[str]=None, remove_encryption_configuration: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, remove_output_location: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None) -> None:
+        def __init__(self, *, encryption_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"]]=None, output_location: typing.Optional[str]=None, remove_encryption_configuration: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, remove_output_location: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None) -> None:
             """
             :param encryption_configuration: ``CfnWorkGroup.ResultConfigurationUpdatesProperty.EncryptionConfiguration``.
             :param output_location: ``CfnWorkGroup.ResultConfigurationUpdatesProperty.OutputLocation``.
@@ -506,7 +514,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             if remove_output_location is not None: self._values["remove_output_location"] = remove_output_location
 
         @builtins.property
-        def encryption_configuration(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.EncryptionConfigurationProperty"]]]:
+        def encryption_configuration(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.EncryptionConfiguration``.
 
             see
@@ -524,7 +532,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('output_location')
 
         @builtins.property
-        def remove_encryption_configuration(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def remove_encryption_configuration(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.RemoveEncryptionConfiguration``.
 
             see
@@ -533,7 +541,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('remove_encryption_configuration')
 
         @builtins.property
-        def remove_output_location(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def remove_output_location(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.RemoveOutputLocation``.
 
             see
@@ -585,7 +593,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.WorkGroupConfigurationProperty", jsii_struct_bases=[], name_mapping={'bytes_scanned_cutoff_per_query': 'bytesScannedCutoffPerQuery', 'enforce_work_group_configuration': 'enforceWorkGroupConfiguration', 'publish_cloud_watch_metrics_enabled': 'publishCloudWatchMetricsEnabled', 'requester_pays_enabled': 'requesterPaysEnabled', 'result_configuration': 'resultConfiguration'})
     class WorkGroupConfigurationProperty():
-        def __init__(self, *, bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number]=None, enforce_work_group_configuration: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, requester_pays_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, result_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.ResultConfigurationProperty"]]]=None) -> None:
+        def __init__(self, *, bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number]=None, enforce_work_group_configuration: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, requester_pays_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, result_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationProperty"]]=None) -> None:
             """
             :param bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationProperty.BytesScannedCutoffPerQuery``.
             :param enforce_work_group_configuration: ``CfnWorkGroup.WorkGroupConfigurationProperty.EnforceWorkGroupConfiguration``.
@@ -614,7 +622,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('bytes_scanned_cutoff_per_query')
 
         @builtins.property
-        def enforce_work_group_configuration(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def enforce_work_group_configuration(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.EnforceWorkGroupConfiguration``.
 
             see
@@ -623,7 +631,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('enforce_work_group_configuration')
 
         @builtins.property
-        def publish_cloud_watch_metrics_enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def publish_cloud_watch_metrics_enabled(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.PublishCloudWatchMetricsEnabled``.
 
             see
@@ -632,7 +640,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('publish_cloud_watch_metrics_enabled')
 
         @builtins.property
-        def requester_pays_enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def requester_pays_enabled(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.RequesterPaysEnabled``.
 
             see
@@ -641,7 +649,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('requester_pays_enabled')
 
         @builtins.property
-        def result_configuration(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.ResultConfigurationProperty"]]]:
+        def result_configuration(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationProperty"]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.ResultConfiguration``.
 
             see
@@ -661,7 +669,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.WorkGroupConfigurationUpdatesProperty", jsii_struct_bases=[], name_mapping={'bytes_scanned_cutoff_per_query': 'bytesScannedCutoffPerQuery', 'enforce_work_group_configuration': 'enforceWorkGroupConfiguration', 'publish_cloud_watch_metrics_enabled': 'publishCloudWatchMetricsEnabled', 'remove_bytes_scanned_cutoff_per_query': 'removeBytesScannedCutoffPerQuery', 'requester_pays_enabled': 'requesterPaysEnabled', 'result_configuration_updates': 'resultConfigurationUpdates'})
     class WorkGroupConfigurationUpdatesProperty():
-        def __init__(self, *, bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number]=None, enforce_work_group_configuration: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, remove_bytes_scanned_cutoff_per_query: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, requester_pays_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, result_configuration_updates: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.ResultConfigurationUpdatesProperty"]]]=None) -> None:
+        def __init__(self, *, bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number]=None, enforce_work_group_configuration: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, remove_bytes_scanned_cutoff_per_query: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, requester_pays_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, result_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationUpdatesProperty"]]=None) -> None:
             """
             :param bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.BytesScannedCutoffPerQuery``.
             :param enforce_work_group_configuration: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.EnforceWorkGroupConfiguration``.
@@ -692,7 +700,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('bytes_scanned_cutoff_per_query')
 
         @builtins.property
-        def enforce_work_group_configuration(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def enforce_work_group_configuration(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.EnforceWorkGroupConfiguration``.
 
             see
@@ -701,7 +709,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('enforce_work_group_configuration')
 
         @builtins.property
-        def publish_cloud_watch_metrics_enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def publish_cloud_watch_metrics_enabled(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.PublishCloudWatchMetricsEnabled``.
 
             see
@@ -710,7 +718,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('publish_cloud_watch_metrics_enabled')
 
         @builtins.property
-        def remove_bytes_scanned_cutoff_per_query(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def remove_bytes_scanned_cutoff_per_query(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.RemoveBytesScannedCutoffPerQuery``.
 
             see
@@ -719,7 +727,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('remove_bytes_scanned_cutoff_per_query')
 
         @builtins.property
-        def requester_pays_enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def requester_pays_enabled(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.RequesterPaysEnabled``.
 
             see
@@ -728,7 +736,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
             return self._values.get('requester_pays_enabled')
 
         @builtins.property
-        def result_configuration_updates(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.ResultConfigurationUpdatesProperty"]]]:
+        def result_configuration_updates(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationUpdatesProperty"]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.ResultConfigurationUpdates``.
 
             see
@@ -749,7 +757,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroupProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'description': 'description', 'recursive_delete_option': 'recursiveDeleteOption', 'state': 'state', 'tags': 'tags', 'work_group_configuration': 'workGroupConfiguration', 'work_group_configuration_updates': 'workGroupConfigurationUpdates'})
 class CfnWorkGroupProps():
-    def __init__(self, *, name: str, description: typing.Optional[str]=None, recursive_delete_option: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, state: typing.Optional[str]=None, tags: typing.Optional["CfnWorkGroup.TagsProperty"]=None, work_group_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.WorkGroupConfigurationProperty"]]]=None, work_group_configuration_updates: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]]]=None) -> None:
+    def __init__(self, *, name: str, description: typing.Optional[str]=None, recursive_delete_option: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, state: typing.Optional[str]=None, tags: typing.Optional["CfnWorkGroup.TagsProperty"]=None, work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]]=None, work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]]=None) -> None:
         """Properties for defining a ``AWS::Athena::WorkGroup``.
 
         :param name: ``AWS::Athena::WorkGroup.Name``.
@@ -793,7 +801,7 @@ class CfnWorkGroupProps():
         return self._values.get('description')
 
     @builtins.property
-    def recursive_delete_option(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def recursive_delete_option(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::Athena::WorkGroup.RecursiveDeleteOption``.
 
         see
@@ -820,7 +828,7 @@ class CfnWorkGroupProps():
         return self._values.get('tags')
 
     @builtins.property
-    def work_group_configuration(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.WorkGroupConfigurationProperty"]]]:
+    def work_group_configuration(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
 
         see
@@ -829,7 +837,7 @@ class CfnWorkGroupProps():
         return self._values.get('work_group_configuration')
 
     @builtins.property
-    def work_group_configuration_updates(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]]]:
+    def work_group_configuration_updates(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
         see
